====================
The ``lino`` package
====================





.. raw:: html

    <a class="reference external" 
    href="http://lino.readthedocs.io/en/latest/?badge=latest"><img
    alt="Documentation Status"
    src="https://readthedocs.org/projects/lino/badge/?version=latest"
    /></a> <a class="reference external"
    href="https://coveralls.io/github/lino-framework/book?branch=master"><img
    alt="coverage"
    src="https://coveralls.io/repos/github/lino-framework/book/badge.svg?branch=master"
    /></a> <a class="reference external"
    href="https://travis-ci.org/lino-framework/book?branch=stable"><img
    alt="build"
    src="https://travis-ci.org/lino-framework/book.svg?branch=stable"
    /></a> <a class="reference external"
    href="https://pypi.python.org/pypi/lino/"><img alt="pypi_v"
    src="https://img.shields.io/pypi/v/lino.svg" /></a> <a
    class="reference external"
    href="https://pypi.python.org/pypi/lino/"><img alt="pypi_license"
    src="https://img.shields.io/pypi/l/lino.svg" /></a>

Lino is a high-level framework for writing desktop-like customized
database applications based on `Django <https://www.djangoproject.com/>`_
and `Sencha ExtJS <http://www.sencha.com/products/extjs/>`_.
Lino applications are Django projects
where the application developer does not need to write any
URLconf, HTML nor CSS (`more <http://lino-framework.org/about/what.html>`__).
Examples of Lino applications are
`Lino Welfare <http://welfare.lino-framework.org>`__,
`Lino Così <http://cosi.lino-framework.org>`__
or
`Lino Voga <http://voga.lino-framework.org>`__
(`more <http://lino-framework.org/about/projects.html>`__)

The central project homepage is http://www.lino-framework.org


